oc\_ocdm.graph.entities.bibliographic.citation module
-----------------------------------------------------

.. automodule:: oc_ocdm.graph.entities.bibliographic.citation
   :members:
   :undoc-members:
   :show-inheritance:
